summaryrefslogtreecommitdiffstats
path: root/kpovmodeler/pmrainbowedit.h
diff options
context:
space:
mode:
Diffstat (limited to 'kpovmodeler/pmrainbowedit.h')
-rw-r--r--kpovmodeler/pmrainbowedit.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/kpovmodeler/pmrainbowedit.h b/kpovmodeler/pmrainbowedit.h
index e2c4698d..be91f895 100644
--- a/kpovmodeler/pmrainbowedit.h
+++ b/kpovmodeler/pmrainbowedit.h
@@ -42,9 +42,9 @@ class PMRainbowEdit : public PMTextureBaseEdit
typedef PMTextureBaseEdit Base;
public:
/**
* Creates a PMRainbowEdit with tqparent and name
*/
- PMRainbowEdit( TQWidget* tqparent, const char* name = 0 );
+ PMRainbowEdit( TQWidget* parent, const char* name = 0 );
/** */
virtual void displayObject( PMObject* o );
@@ -42,9 +42,9 @@ class PMRainbowEdit : public PMTextureBaseEdit
public:
/**
- * Creates a PMRainbowEdit with tqparent and name
+ * Creates a PMRainbowEdit with parent and name
*/